@@ -7,6 +7,7 @@ class Proxy(object):
     _PROXY = True
     _path = None
     _propclass = False
+    _cached = False
 
     def __init__(self, *args, **kwargs):
         self._kwargs = kwargs
@@ -14,6 +15,9 @@ class Proxy(object):
         self._args = args
         self._id = None
 
+        if '_cached' in kwargs:
+            self._cached = kwargs['_cached']
+
         if '_id' in kwargs:
             self._id = kwargs['_id']
         elif self._path and self._propclass == False:
